# -*- coding: utf-8 -*-
# Generated by Django 1.11.29 on 2021-01-26 14:47
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djelmah', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='djelmahhost',
            name='api_key',
            field=models.CharField(blank=True, max_length=128),
        ),
        migrations.AlterField(
            model_name='djelmahhost',
            name='username',
            field=models.CharField(blank=True, max_length=150),
        ),
    ]
