{% extends 'djelmah/base.html' %}

{% block content %}

<div class="row mt-3">
    <div class="col-md-4 offset-md-4">
        <div class="card">
            <div class="card-body">
                <form method="post">
                    {% csrf_token %}
                    <div class="form-group">
                        <input
                            type="text"
                            class="form-control"
                            placeholder="Username"
                            name="username"
                        />
                    </div>
                    <div class="form-group">
                        <input
                            type="password"
                            class="form-control"
                            placeholder="Password"
                            name="password"
                        />
                    </div>
                    <button
                        type="submit"
                        class="btn btn-primary"
                    >
                        Login
                    </button>
                </form>
            </div>
        </div>
    </div>
</div>

{% endblock %}
